@@ -319,10 +319,14 @@ class Requests(_defaults_.Defaults):
 				if not response.success: return self.response(response)
 
 				# handler.
-				return self.response("Successfully checked if the user is authenticated.", {
+				try:
+					email = request.user.email
+				except AttributeError:
+					email = None
+				return self.success("Successfully checked if the user is authenticated.", {
 					"authenticated":request.user.username != None and request.user.is_authenticated == True,
 					"username":request.user.username,
-					#"email":request.user.email,
+					"email":email,
 				})
 
 			# catch error.
